<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>SyncthingDirActions</name>
    <message>
        <location filename="../syncthingdiractions.cpp" line="34"/>
        <source>Status: not available anymore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="43"/>
        <source>Folder info for %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="44"/>
        <source>Status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="73"/>
        <source>Global: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="74"/>
        <source>Local: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="75"/>
        <source>Last scan time: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdiractions.cpp" line="76"/>
        <source>Rescan interval: %1 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdiractions.cpp" line="81"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 item out-of-sync</numerusform>
            <numerusform>%1 items out-of-sync</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemAction</name>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="288"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="159"/>
        <source>Rescan selected items</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="178"/>
        <source>Rescan selected folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="161"/>
        <location filename="../syncthingfileitemaction.cpp" line="178"/>
        <location filename="../syncthingfileitemaction.cpp" line="209"/>
        <source>Rescan &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="191"/>
        <source>Resume selected folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="194"/>
        <source>Pause selected folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="209"/>
        <source>Rescan containing folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="221"/>
        <source>Resume containing folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="191"/>
        <location filename="../syncthingfileitemaction.cpp" line="221"/>
        <source>Resume &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="225"/>
        <source>Pause containing folders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="194"/>
        <location filename="../syncthingfileitemaction.cpp" line="225"/>
        <source>Pause &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="249"/>
        <source>Not a shared directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemaction.cpp" line="283"/>
        <source>Select Syncthing config ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingFileItemActionStaticData</name>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="84"/>
        <source>Syncthing connection error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="104"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="112"/>
        <source>Select Syncthing config file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="138"/>
        <source>Syncthing config file can not be automatically located</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="145"/>
        <source>Unable to load Syncthing config from &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="154"/>
        <source>Syncthing config from &quot;%1&quot; does not contain GUI address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>Enter API key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="166"/>
        <source>The selected config file does not contain an API key. Please enter the API key manually:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="168"/>
        <source>No API key supplied for &quot;%1&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfileitemactionstaticdata.cpp" line="127"/>
        <source>(still using config from &quot;%1&quot;)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SyncthingMenuAction</name>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="69"/>
        <source>Syncthing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="80"/>
        <source>Syncthing - connecting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingmenuaction.cpp" line="82"/>
        <source>Syncthing - not connected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
